"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parse = parse;

var _syntaxTokenizer = require("./syntax-tokenizer");

function parse(syntax) {
  return parseTokens((0, _syntaxTokenizer.tokenize)(syntax));
}

function parseTokens(tokens) {
  var ast = [];

  while (tokens.length) {
    var token = tokens.shift();

    if (token.type === _syntaxTokenizer.tokenType.CLOSE_PARENTHESIS) {
      return {
        ast: ast,
        token: token
      };
    } else if (token.type === _syntaxTokenizer.tokenType.OPEN_PARENTHESIS) {
      var childResult = parseTokens(tokens);
      ast.push(toLoopNode(childResult.ast, childResult.token));
      continue;
    }

    ast.push(toTimeNode(token));
  }

  return ast;
}

function toTimeNode(timeToken) {
  return {
    timeSec: timeToken.timeMin * 60
  };
}

function toLoopNode(childNodes, loopToken) {
  return {
    childNodes: childNodes,
    loop: loopToken.loop
  };
}