"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tokenize = tokenize;
exports.tokenType = void 0;
var LOOP_REGEX = /\)(?:[0-9]+|)/;
var P_REGEX = /p[0-9]+/;
var tokenType = {
  TIME: 1,
  OPEN_PARENTHESIS: 2,
  CLOSE_PARENTHESIS: 3
};
exports.tokenType = tokenType;

function tokenize(syntax) {
  var tokens = [];

  for (var i = 0; i < syntax.length; i++) {
    var ch = syntax.charAt(i);

    switch (ch) {
      case '(':
        tokens.push({
          type: tokenType.OPEN_PARENTHESIS
        });
        break;

      case ')':
        {
          var loopSyntax = syntax.substring(i);
          var found = loopSyntax.match(LOOP_REGEX);

          if (found) {
            var loop = found[0].length === 1 ? 0 : parseInt(loopSyntax.substring(1, found[0].length));
            tokens.push({
              type: tokenType.CLOSE_PARENTHESIS,
              loop: loop
            });
            i += found[0].length - 1;
          }

          break;
        }

      case 'p':
        {
          var pSyntax = syntax.substring(i);

          var _found = pSyntax.match(P_REGEX);

          if (_found) {
            var timeMin = pSyntax.substring(1, _found[0].length);
            tokens.push({
              type: tokenType.TIME,
              timeMin: parseInt(timeMin)
            });
            i += _found[0].length - 1;
          }

          break;
        }

      case ' ':
        continue;

      default:
        return [];
    }
  }

  return tokens;
}